@@ -43,7 +43,7 @@
 // XPConnect includes
 #include "nsIXPConnect.h"
 #include "nsIScriptSecurityManager.h"
-#include "nsICodebasePrincipal.h"
+#include "nsIPrincipal.h"
 
 // XPCOM includes
 #include "nsIServiceManager.h"
@@ -493,7 +493,7 @@ nsBuiltinSchemaCollection::GetBuiltinType(const nsAString& aName,
     rv = CallQueryInterface(sup, aType);
   }
   else {
-    nsCOMPtr<nsIAtom> typeName = dont_AddRef(NS_NewAtom(aName));
+    nsCOMPtr<nsIAtom> typeName = do_GetAtom(aName);
     PRUint16 typeVal;
     if (typeName == nsSchemaAtoms::sAnyType_atom) {
       typeVal = nsISchemaBuiltinType::BUILTIN_TYPE_ANYTYPE;
@@ -813,10 +813,7 @@ nsSchemaLoader::GetResolvedURI(const nsAString& aSchemaURI,
     nsCOMPtr<nsIPrincipal> principal;
     rv = secMan->GetSubjectPrincipal(getter_AddRefs(principal));
     if (NS_SUCCEEDED(rv)) {
-      nsCOMPtr<nsICodebasePrincipal> codebase = do_QueryInterface(principal);
-      if (codebase) {
-        codebase->GetURI(getter_AddRefs(baseURI));
-      }
+      principal->GetURI(getter_AddRefs(baseURI));
     }
     
     rv = NS_NewURI(aURI, aSchemaURI, nsnull, baseURI);
@@ -859,15 +856,15 @@ nsSchemaLoader::Load(const nsAString& schemaURI,
     return rv;
   }
 
-  rv = request->OpenRequest("GET",
-                            spec.get(),
-                            PR_FALSE, nsnull, nsnull);
+  const nsAString& empty = EmptyString();
+  rv = request->OpenRequest(NS_LITERAL_CSTRING("GET"), spec, PR_FALSE, empty,
+                            empty);
   if (NS_FAILED(rv)) {
     return rv;
   }
 
   // Force the mimetype of the returned stream to be xml.
-  rv = request->OverrideMimeType("text/xml");
+  rv = request->OverrideMimeType(NS_LITERAL_CSTRING("text/xml"));
   if (NS_FAILED(rv)) {
     return rv;
   }
@@ -915,15 +912,15 @@ nsSchemaLoader::LoadAsync(const nsAString& schemaURI,
     return rv;
   }
 
-  rv = request->OpenRequest("GET",
-                            spec.get(),
-                            PR_TRUE, nsnull, nsnull);
+  const nsAString& empty = EmptyString();
+  rv = request->OpenRequest(NS_LITERAL_CSTRING("GET"), spec, PR_TRUE, empty,
+                            empty);
   if (NS_FAILED(rv)) {
     return rv;
   }
 
   // Force the mimetype of the returned stream to be xml.
-  rv = request->OverrideMimeType("text/xml");
+  rv = request->OverrideMimeType(NS_LITERAL_CSTRING("text/xml"));
   if (NS_FAILED(rv)) {
     return rv;
   }
@@ -1164,10 +1161,9 @@ nsSchemaLoader::ProcessElement(nsSchema* aSchema,
   else {
     nsAutoString value;
     nsSchemaElement* elementInst;
+    const nsAString& empty = EmptyString();
 
-    rv = aElement->GetAttributeNS(NS_LITERAL_STRING(""), 
-                                  NS_LITERAL_STRING("name"), 
-                                  value);
+    rv = aElement->GetAttributeNS(empty, NS_LITERAL_STRING("name"), value);
     
     if (NS_FAILED(rv))
       return rv;
@@ -1183,22 +1179,19 @@ nsSchemaLoader::ProcessElement(nsSchema* aSchema,
     elementInst->SetMaxOccurs(maxOccurs);
 
     nsAutoString defaultValue, fixedValue;
-    rv = aElement->GetAttributeNS(NS_LITERAL_STRING(""), 
-                                  NS_LITERAL_STRING("default"),
+    rv = aElement->GetAttributeNS(empty, NS_LITERAL_STRING("default"),
                                   defaultValue);
     if (NS_FAILED(rv))
       return rv;
     
-    rv = aElement->GetAttributeNS(NS_LITERAL_STRING(""), 
-                                  NS_LITERAL_STRING("fixed"), 
+    rv = aElement->GetAttributeNS(empty, NS_LITERAL_STRING("fixed"), 
                                   fixedValue);
     if (NS_FAILED(rv))
       return rv;
-    
+
     elementInst->SetConstraints(defaultValue, fixedValue);
 
-    rv = aElement->GetAttributeNS(NS_LITERAL_STRING(""),
-                                  NS_LITERAL_STRING("nillable"), value);
+    rv = aElement->GetAttributeNS(empty, NS_LITERAL_STRING("nillable"), value);
     if (NS_FAILED(rv))
       return rv;
     value.Trim(" \r\n\t");
@@ -1207,8 +1200,7 @@ nsSchemaLoader::ProcessElement(nsSchema* aSchema,
     if (value.Equals(NS_LITERAL_STRING("true")))
       flags |= nsSchemaElement::NILLABLE;
 
-    rv = aElement->GetAttributeNS(NS_LITERAL_STRING(""), 
-                                  NS_LITERAL_STRING("abstract"), value);
+    rv = aElement->GetAttributeNS(empty, NS_LITERAL_STRING("abstract"), value);
     if (NS_FAILED(rv))
       return rv;
     value.Trim(" \r\n\t");
@@ -1236,8 +1228,7 @@ nsSchemaLoader::ProcessElement(nsSchema* aSchema,
       flags |= nsSchemaElement::FORM_QUALIFIED;
     }
     else {
-      rv = aElement->GetAttributeNS(NS_LITERAL_STRING(""), 
-                                    NS_LITERAL_STRING("form"), 
+      rv = aElement->GetAttributeNS(empty, NS_LITERAL_STRING("form"), 
                                     value);
       if (NS_FAILED(rv))
         return rv;
@@ -1761,8 +1752,7 @@ nsSchemaLoader::ProcessSimpleContentRestriction(nsSchema* aSchema,
   nsSchemaRestrictionType* restrictionInst;
   nsCOMPtr<nsISchemaSimpleType> simpleBase;
  
-  restrictionInst = new nsSchemaRestrictionType(aSchema, 
-                                                NS_LITERAL_STRING(""));
+  restrictionInst = new nsSchemaRestrictionType(aSchema, EmptyString());
   if (!restrictionInst) {
     return NS_ERROR_OUT_OF_MEMORY;
   }
@@ -1964,8 +1954,7 @@ nsSchemaLoader::ProcessComplexContent(nsSchema* aSchema,
           if (baseGroup) {
             // Create a new model group that's going to be the a sequence
             // of the base model group and the content below
-            sequenceInst = new nsSchemaModelGroup(aSchema,
-                                                  NS_LITERAL_STRING(""));
+            sequenceInst = new nsSchemaModelGroup(aSchema, EmptyString());
             if (!sequenceInst) {
               return NS_ERROR_OUT_OF_MEMORY;
             }
