@@ -121,16 +121,17 @@ public:
   PRUint8      compression;
   PRUint8      flags;
 
+#ifndef STANDALONE
   /**
    * GetModTime
    *
    * Utility to get an NSPR-friendly formatted string
    * representing the last modified time of this item.
    * 
-   * @return nsprstr    an NSPR-friendly string representation 
-   *                    of the modification time
+   * @return nsprstr    The modification time in PRTime
    */
-  char *GetModTime();
+  PRTime GetModTime();
+#endif
 
   nsZipItem();
   ~nsZipItem();
@@ -232,7 +233,8 @@ public:
   PRInt32 ExtractFile(const char * zipEntry, const char * aOutname,
                       PRFileDesc* aFd);
 
-  PRInt32 ExtractItemToFileDesc(nsZipItem* item, PRFileDesc* outFD,
+  PRInt32 ExtractFileToFileDesc(const char * zipEntry, PRFileDesc* outFD,
+                                nsZipItem **outItem,
                                 PRFileDesc* aFd);
 
   /**
