@@ -40,7 +40,7 @@
 
 #include <stdlib.h>
 
-#if defined(XP_WIN)
+#if defined( XP_WIN )
 #include "prmem.h"
 #include "nsString.h"
 #include "nsLiteralString.h"
@@ -48,11 +48,6 @@
 #include <windows.h>
 #endif
 
-#if defined(XP_MACOSX)
-#include <Processes.h>
-#include "nsILocalFileMac.h"
-#endif
-
 //-------------------------------------------------------------------//
 // nsIProcess implementation
 //-------------------------------------------------------------------//
@@ -88,7 +83,7 @@ nsProcess::Init(nsIFile* executable)
 }
 
 
-#if defined(XP_WIN)
+#if defined( XP_WIN )
 static int assembleCmdLine(char *const *argv, char **cmdLine)
 {
     char *const *arg;
@@ -198,13 +193,6 @@ nsProcess::Run(PRBool blocking, const char **args, PRUint32 count, PRUint32 *pid
 {
     nsresult rv = NS_OK;
 
-#if defined(XP_MACOSX)
-    // You can't pass arguments to mac apps, tell the caller that it
-    // just aint going to work.
-    if (count) {
-        return NS_ERROR_INVALID_ARG;
-    }
-#else
     // make sure that when we allocate we have 1 greater than the
     // count since we need to null terminate the list for the argv to
     // pass into PR_CreateProcess
@@ -223,9 +211,8 @@ nsProcess::Run(PRBool blocking, const char **args, PRUint32 count, PRUint32 *pid
     my_argv[0] = mTargetPath.BeginWriting();
     // null terminate the array
     my_argv[count+1] = NULL;
-#endif
 
-#if defined(XP_WIN)
+ #if defined(XP_WIN)
     STARTUPINFO startupInfo;
     PROCESS_INFORMATION procInfo;
     BOOL retVal;
@@ -290,56 +277,6 @@ nsProcess::Run(PRBool blocking, const char **args, PRUint32 count, PRUint32 *pid
             rv = PR_FAILURE;
     }
 
-#elif defined(XP_MACOSX)
-    FSSpec resolvedSpec;
-    OSErr err = noErr;
-
-    nsCOMPtr<nsILocalFileMac> macExecutable = do_QueryInterface(mExecutable);
-    macExecutable->GetFSSpec(&resolvedSpec);
-
-    LaunchParamBlockRec launchPB;
-    launchPB.launchAppSpec = &resolvedSpec;
-    launchPB.launchAppParameters = NULL;
-    launchPB.launchBlockID = extendedBlock;
-    launchPB.launchEPBLength = extendedBlockLen;
-    launchPB.launchFileFlags = NULL;
-    launchPB.launchControlFlags =
-        launchContinue + launchNoFileFlags + launchUseMinimum;
-    if (!blocking)
-        launchPB.launchControlFlags += launchDontSwitch;
-
-    err = LaunchApplication(&launchPB);
-
-    // NOTE: blocking mode assumes you are running on a thread
-    //       other than the UI thread that has the main event loop
-    if (blocking && err == noErr) {
-        while (1) {
-            ProcessInfoRec info;
-            info.processInfoLength = sizeof(ProcessInfoRec);
-            info.processName = NULL;
-            info.processAppSpec = NULL;
-
-            err = GetProcessInformation(&launchPB.launchProcessSN, &info);
-
-            if (err != noErr) {
-                // The process is no longer in the process manager's internal
-                // list, assume the process is done.
-                err = noErr;
-
-                break;
-            }
-
-            // still running so sleep some more (200 msecs)
-            PR_Sleep(200);
-        }
-    }
-
-    if (err != noErr) {
-        rv = PR_FAILURE;
-    }
-
-    mExitValue = err;
-
 #else
     if ( blocking ) {
         mProcess = PR_CreateProcess(mTargetPath.get(), my_argv, NULL, NULL);
@@ -351,14 +288,11 @@ nsProcess::Run(PRBool blocking, const char **args, PRUint32 count, PRUint32 *pid
     }
 #endif
 
-#if !defined(XP_MACOSX)
     // free up our argv
     nsMemory::Free(my_argv);
-#endif
 
     if (rv != PR_SUCCESS)
         return NS_ERROR_FILE_EXECUTION_FAILED;
-
     return NS_OK;
 }
 
