@@ -49,10 +49,11 @@ public:
     int             Hide(int aDirection);
     
     static void     RowSelected(GtkWidget *aWidget, gint aRow, gint aColumn,
-                                GdkEventButton *aEvent, gpointer aData);
+                               GdkEventButton *aEvent, gpointer aData);
     static void     KeyPressed(GtkWidget *aWidget, GdkEventKey *aEvent, 
                                gpointer aData);
-    static void     ToggleRowSelection(GtkWidget *aEvent, gint aRow);
+    static void     ToggleRowSelection(GtkWidget *aEvent, gint aRow, 
+                               gint aColumn);
 
 /*--------------------------------------------------------------------*
  *   INI Properties
